@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.11_03'; # TRIAL VERSION
+our $VERSION = '1.17_01'; # TRIAL VERSION
 
 
 use 5.006;
@@ -37,7 +37,10 @@ sub import {
   my $pack = caller;
   my $test = Test::Builder->new;
   $test->exported_to($pack);
-  $test->plan(@_);
+  if(defined $_[0] && $_[0] =~ /^(?:no_plan|skip_all|tests)$/)
+  {
+    $test->plan(@_);
+  }
   foreach ( @EXPORT ) {
     $self->export_to_level(1, $self, $_);
   }
@@ -90,9 +93,10 @@ sub script_compiles {
   my $args   = _script(shift);
   my $unix   = shift @$args;
   my $path   = path( $unix );
+  my $pargs  = _perl_args($path);
   my @libs   = map { "-I$_" } grep {!ref($_)} @INC;
   my $dir    = _preload_module();
-  my $cmd    = [ perl, "-I$dir", '-M__TEST_SCRIPT__', '-c', $path, @$args ];
+  my $cmd    = [ perl, @$pargs, "-I$dir", '-M__TEST_SCRIPT__', '-c', $path, @$args ];
   my $stdin  = '';
   my $stdout = '';
   my $stderr = '';
@@ -131,7 +135,7 @@ sub _preload_module
     join ',', 
     # quotemeta is overkill, but it will make sure that characters
     # like " are quoted
-    map { '"' . quotemeta . '"' }
+    map { '"' . quotemeta($_) . '"' }
     grep { ! ref } @INC)
       || die "unable to write $filename: $!";
   close($fh) || die "unable to close $filename: $!";;
@@ -147,8 +151,9 @@ sub script_runs {
   my $opt    = _options(\@_);
   my $unix   = shift @$args;
   my $path   = path( $unix );
+  my $pargs  = _perl_args($path);
   my $dir    = _preload_module();
-  my $cmd    = [ perl, "-I$dir", '-M__TEST_SCRIPT__', $path, @$args ];
+  my $cmd    = [ perl, @$pargs, "-I$dir", '-M__TEST_SCRIPT__', $path, @$args ];
      $stdout = '';
      $stderr = '';
   my $rv     = eval { run3( $cmd, $opt->{stdin}, $opt->{stdout}, $opt->{stderr} ) };
@@ -267,12 +272,26 @@ sub _script {
   }
   if ( _ARRAY($in) ) {
     unless ( scalar grep { not defined _STRING($_) } @$in ) {
-      return $in;     
+      return [ @$in ];
     }
   }
   Carp::croak("Invalid command parameter");
 }
 
+# Determine any extra arguments that need to be passed into Perl.
+# ATM this is just -T.
+sub _perl_args {
+  my($script) = @_;
+  my $fh;
+  my $first_line = '';
+  if(open($fh, "<$script"))
+  {
+    $first_line = <$fh>;
+    close $fh;
+  }
+  (grep /^-.*T/, split /\s+/, $first_line) ? ['-T'] : [];
+}
+
 # Inline some basic Params::Util functions
 
 sub _options {
@@ -315,7 +334,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.11_03
+version 1.17_01
 
 =head1 SYNOPSIS
 
@@ -522,6 +541,10 @@ Original author: Adam Kennedy
 
 Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
+Contributors:
+
+Brendan Byrd
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2006 by Adam Kennedy.
